@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 $|=1;
-# Generates a html page showing various sataus reports about the cluster
-# $Id: clusterstatus.pl,v 1.24 2005/04/13 18:30:46 albertel Exp $
+# Generates a html page showing various status reports about the domain or cluster
+# $Id: clusterstatus.pl,v 1.26 2008/12/25 01:56:03 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -26,14 +26,20 @@ $|=1;
 # http://www.lon-capa.org/
 #
 
-use lib '/home/httpd/lib/perl/';
-use LONCAPA::Configuration;
 use strict;
 
+use lib '/home/httpd/lib/perl/';
+use Apache::lonnet;
+use Apache::lonlocal;
+use LONCAPA::Configuration;
+use LONCAPA::loncgi;
+use LONCAPA::lonauthcgi;
 use LWP::UserAgent();
 use HTTP::Headers;
 use IO::File;
 
+my $perlvar=&LONCAPA::Configuration::read_conf('loncapa.conf');
+
 my %host=();
 my $oneday=60*60*24;
 
@@ -44,19 +50,16 @@ my $mode;
 my $concount=0;
 my $fromcache;
 
-my %domaindescription = ();
-my %domain_auth_def = ();
-my %domain_auth_arg_def = ();
-my %domain_lang_def=();
-my %domain_city=();
-my %domain_longi=();
-my %domain_lati=();
+my %domaininfo = &Apache::lonnet::domain_info();
+my %allhostname = &Apache::lonnet::all_hostnames();
+my (%hostname,%hostip);
+my %hostdom = &Apache::lonnet::all_host_domain();
+my %iphost = &Apache::lonnet::get_iphost();
+my %libserv= &Apache::lonnet::all_library();
 
-my %hostname=();
-my %hostip=();
-my %hostdom=();
-my %hostrole=();
-my %libserv=();
+foreach my $ip (keys(%iphost)) {
+    $hostip{$iphost{$ip}} = $ip;
+}
 
 my $maxusers=0;
 my $maxload=0;
@@ -71,10 +74,10 @@ my $stat_fromcache=0;
 sub select_form {
     my ($def,$name,%hash) = @_;
     my $selectform = "<select name=\"$name\" size=\"1\">\n";
-    foreach (sort keys %hash) {
-        $selectform.="<option value=\"$_\" ".
-            ($_ eq $def ? 'selected' : '').
-                ">".$hash{$_}."</option>\n";
+    foreach my $key (sort(keys(%hash))) {
+        $selectform.="<option value=\"$key\" ".
+            ($key eq $def? 'selected' : '').
+                ">".$hash{$key}."</option>\n";
     }
     $selectform.="</select>";
     return $selectform;
@@ -90,7 +93,7 @@ sub key {
 
 sub hidden {
     my ($name,$value)=@_;
-    print "\n<input type='hidden' name='$name' value='$value' />";
+    print("\n<input type='hidden' name='$name' value='$value' />");
 }
 
 sub request {
@@ -102,11 +105,11 @@ sub request {
 # if fromcache flag is set, only return cached values
     if ($fromcache) {
 	if ($FORM{$key.'_time'}) {
+            $stat_fromcache++;
 	    return $FORM{$key};
-	    $stat_fromcache++;
 	} else {
+            $stat_notyet++;
 	    return 'not_yet';
-	    $stat_notyet++;
 	}
     }
 # normal mode, refresh when expired or not yet present
@@ -118,25 +121,20 @@ sub request {
 	}
     }
     unless ($reply) {
-	unless ($hostname{$local}) { 
-	    $reply='local_unknown'; 
-	} else {
-
-	    my $ua=new LWP::UserAgent(timeout => 10);
-    
+        if ($hostname{$local}) {
+	    my $ua=new LWP::UserAgent(timeout => 20);
 	    my $request=new HTTP::Request('GET',
 					  "http://".$hostname{$local}.$url);
-	    $request->authorization_basic('lonadm','litelite');
-
 	    my $response=$ua->request($request);
-
-	    unless ($response->is_success) { 
+	    if ($response->is_success) {
+                $reply=$response->content;
+                chomp($reply);
+            } else {
 		$reply='local_error'; 
-	    } else {
-		$reply=$response->content;
-		chomp($reply);
 	    }
-	}
+	} else {
+            $reply='local_unknown';
+        }
 	&hidden($key.'_time',time);
     }
     &hidden($key,$reply);
@@ -198,149 +196,166 @@ sub otherwindow {
 
 sub login {
     my $local=shift;
-    print &otherwindow($local,'/adm/login?domain='.$perlvar{'lonDefDomain'},
-		       'Login');
+    print(&otherwindow($local,'/adm/login?domain='.$perlvar{'lonDefDomain'},
+		       'Login'));
 }
 
 sub runloncron {
     my $local=shift;
-    print &otherwindow($local,'/cgi-bin/loncron.pl','Run loncron');
+    print(&otherwindow($local,'/cgi-bin/loncron.pl',&Apache::lonlocal::mt('Run loncron')));
 }
 
 sub loncron {
     my $local=shift;
-    print &otherwindow($local,'/lon-status','loncron');
+    print(&otherwindow($local,'/lon-status','loncron'));
 }
 
 sub lonc {
     my $local=shift;
-    print &otherwindow($local,'/lon-status/loncstatus.txt','lonc');
+    print(&otherwindow($local,'/lon-status/loncstatus.txt','lonc'));
 }
 
 sub lond {
     my $local=shift;
-    print &otherwindow($local,'/lon-status/londstatus.txt','lond');
+    print(&otherwindow($local,'/lon-status/londstatus.txt','lond'));
 }
 
 sub users {
     my $local=shift;
-    print &otherwindow($local,'/cgi-bin/userstatus.pl','Users');
+    print(&otherwindow($local,'/cgi-bin/userstatus.pl',&Apache::lonlocal::mt('Users')));
 }
 
 sub versions {
     my $local=shift;
-    print &otherwindow($local,'/cgi-bin/lonversions.pl','Versions');
+    print(&otherwindow($local,'/cgi-bin/lonversions.pl',&Apache::lonlocal::mt('Versions')));
 }
 
 sub server {
     my $local=shift;
-    print &otherwindow($local,'/server-status','Server Status');
+    print(&otherwindow($local,'/server-status',&Apache::lonlocal::mt('Server Status')));
 }
 
 sub announcement {
     my $local=shift;
-    print &otherwindow($local,'/announcement.txt','Announcement');
+    print(&otherwindow($local,'/announcement.txt',&Apache::lonlocal::mt('Announcement')));
 }
 
 sub takeonline {
     my $local=shift;
-    print &otherwindow($local,'/cgi-bin/takeonline.pl','Take online');
+    print(&otherwindow($local,'/cgi-bin/takeonline.pl',&Apache::lonlocal::mt('Take online')));
 }
 
 sub takeoffline {
     my $local=shift;
-    print &otherwindow($local,'/cgi-bin/takeoffline.pl','Take offline');
+    print(&otherwindow($local,'/cgi-bin/takeoffline.pl',&Apache::lonlocal::mt('Take offline')));
 }
 
 sub reroute {
     my ($local,$remote)=@_;
-    print &otherwindow($local,'/cgi-bin/takeoffline.pl?'.
+    print(&otherwindow($local,'/cgi-bin/takeoffline.pl?'.
 		       $hostname{$remote}.'&'.$hostdom{$local}
-		       ,$remote)."\n";
+		       ,$remote)."\n");
 }
 
 sub allreroutes {
     my $local=shift;
     &takeoffline($local);
-    print ' Reroute to: <font size="1">';
+    print(&Apache::lonlocal::mt('Reroute to:').' <font size="1">');
     foreach my $remote (sort keys %hostname) {
 	unless ($local eq $remote) {
 	    &reroute($local,$remote);
 	}
     }
-    print '</font>';
+    print('</font>');
 }
 
 # ========================================================= Produce a green bar
 sub bar {
     my $parm=shift;
     my $number=int($parm+0.5);
-    print "<table><tr><td bgcolor='#225522'><font color='#225522'>";
+    print('<table><tr><td bgcolor="#225522"><font color="#225522">');
     for (my $i=0;$i<$number;$i++) {
 	print "+";
     }
-    print "</font></table>";
+    print("</font></table>");
 }
 
 # ========================================================== Show server status
 
 sub serverstatus {
     my ($local,$trouble)=@_;
-    print (<<ENDHEADER);
+    my $hostrole;
+    if (exists($libserv{$local})) {
+        $hostrole = 'library';
+    } else {
+        $hostrole = 'access';
+    }
+    my %lt = &Apache::lonlocal::texthash(
+                                          rero => 'Reroute:',
+                                          vers => 'Version:',
+                                          load => 'Load:',
+                                          acti => 'Active Users:',
+                                          rpms => 'RPMs',
+                                          mysq => 'MySQL Database:',
+                                          notc => 'Not connected',
+                                          lonc => 'loncron errors',
+                                         );
+   
+    print(<<ENDHEADER);
 <a name="$local" />
 <table width="100%" bgcolor="#225522" cellspacing="2" cellpadding="2" border="0">
 <tr><td bgcolor="#BBDDBB"><font color="#225522" face="arial"><b>
-$local $hostdom{$local}</b> <tt>($hostname{$local}; $hostrole{$local})</tt>
-<br />$domaindescription{$hostdom{$local}}
-$domain_city{$hostdom{$local}}
+$local $hostdom{$local}</b> <tt>($hostname{$local}); $hostrole</tt>
+<br />$domaininfo{$hostdom{$local}}{'description'}
+$domaininfo{$hostdom{$local}}{'city'}
 </font></th></tr><tr><td bgcolor="#DDDDBB"><font color="#225522">
 ENDHEADER
     &login($local);&server($local);&users($local);&versions($local);
     &announcement($local);
     &loncron($local);&lond($local);&lonc($local);&runloncron($local);
-    print "</font></td></tr>";
+    print("</font></td></tr>");
     if ($trouble) {
-	print ("<tr><td bgcolor='#DDBBBB'><font color='#552222' size='+2'>$trouble</font></td></tr>");
+	print("<tr><td bgcolor='#DDBBBB'><font color='#552222' size='+2'>$trouble</font></td></tr>");
     }
-    print "<tr><td bgcolor='#BBBBBB'>";
+    print("<tr><td bgcolor='#BBBBBB'>");
 # re-routing
     if ($host{$local.'_reroute'}) {
-	print "<br />Reroute: ".$host{$local.'_reroute'};
+	print('<br />'.$lt{'rero'}.' '.$host{$local.'_reroute'});
 	&takeonline($local);
     }
 # version
     if ($host{$local.'_version'}) {
-	print "<br />Version: ".$host{$local.'_version'}
+	print('<br />'.$lt{'vers'}.' '.$host{$local.'_version'});
     }
 # load
     if (($host{$local.'_load_doomed'}>0.5) || ($mode eq 'load_doomed')) {
-	print "<br />Load: ".$host{$local.'_load'}
+	print('<br />'.$lt{'load'}.' '.$host{$local.'_load'});
     }
 # users
     if (($host{$local.'_users_doomed'}>10) || ($mode eq 'users_doomed')) {
-	print "<br />Active Users: ".$host{$local.'_users'}
+	print('<br />'.$lt{'acti'}.' '.$host{$local.'_users'});
     }
 
 # checkrpms
     if ($host{$local.'_checkrpms'}) {
-	print "<br />RPMs: ".$host{$local.'_checkrpms'}
+	print('<br />'.$lt{'rpms'}.' '.$host{$local.'_checkrpms'});
     }
 # mysql
     if ($host{$local.'_mysql'}) {
-	print "<br />MySQL Database: ".$host{$local.'_mysql'}
+	print('<br />'.$lt{'mysq'}.' '.$host{$local.'_mysql'});
     }
 # connections
     if ($host{$local.'_notconnected'}) {
-	print "<br />Not connected: ";
-	foreach (split(/ /,$host{$local.'_notconnected'})) {
-	    if ($_) {
-		print " <a href='#$_'>$_</a>";
+	print('<br />'.$lt{'notc'}.' ');
+	foreach my $item (split(/ /,$host{$local.'_notconnected'})) {
+	    if ($item) {
+		print(' <a href="#$item">'.$item.'</a>');
 	    }
 	}
     }
 # errors
     if ($host{$local.'_errors'}) {
-	print "<br />loncron errors: ".$host{$local.'_errors'};
+	print('<br />'.$lt{'lonc'}.' '.$host{$local.'_errors'});
     }
     print "</td></tr><tr><td bgcolor='#DDDDDD'>";
     &allreroutes($local);
@@ -380,7 +395,7 @@ sub mainloop {
     &resetvars();
 # ==================================================== Main Loop over all Hosts
 
-foreach my $local (sort keys %hostname) {
+foreach my $local (sort(keys(%hostname))) {
     $host{$local.'_unresponsive_doomed'}=0;
 # -- Check general status
     &statuslist($local,'General');
@@ -450,7 +465,7 @@ foreach my $local (sort keys %hostname) {
 	$host{$local.'_unresponsive_doomed'}++;
     } else {
 	if ((time-$mysql{'time'})>(7*$oneday)) {
-	    if ($hostrole{$local} eq 'library') {
+	    if (exists($libserv{$local})) {
 		$host{$local.'_mysql'}='Stale.';
 		$host{$local.'_mysql_doomed'}=1;
 	    }
@@ -527,7 +542,7 @@ sub reports {
 		    my $cellcolor='#BBDDBB';
 		    if ($local eq $remote) { $cellcolor='#99DD99'; }
 		    print 
-'<td bgcolor="'.$cellcolor.'"><font color="#225522" face="arial"><b>ok</b></td>';
+'<td bgcolor="'.$cellcolor.'"><font color="#225522" face="arial"><b>'.&Apache::lonlocal::mt('ok').'</b></td>';
 		} else {
 		    my $cellcolor='#DDCCAA';
 		    if ($connectionstatus{$local.'_TO_'.$remote} eq 'local_error') {
@@ -553,27 +568,27 @@ sub reports {
 # Users
 	if ($maxusers) {
 	    my $factor=50/$maxusers;
-	    print "<h3>Total active user(s): $totalusers</h3>". 
-       "<table cellspacing='3' cellpadding='3' border='0' bgcolor='#225522'>";
+	    print '<h3>'.&Apache::lonlocal::mt('Total active user(s)').': '.$totalusers.'</h3>'. 
+                  '<table cellspacing="3" cellpadding="3" border="0" bgcolor="#225522">';
 
 	    foreach my $local (sort keys %hostname) {
 		if (defined($host{$local.'_users'})) {
 		    print 
 '<tr><td bgcolor="#BBDDBB"><font face="arial" color="#225522" size="+1">'.$local.
 			'</font><br /><font size="-2">'.
-			$domaindescription{$hostdom{$local}}.
+			$domaininfo{$hostdom{$local}}{'description'}.
 		       '</font></td><td bgcolor="#DDDDBB">';
 		    &users($local);
 		    print 
 	      '</td><td bgcolor="#DDDDBB"><font face="arial" color="#225522">'.
 	      $host{$local.'_users'}.'</font></td><td bgcolor="#DDDDBB"';
 		    &bar($factor*$host{$local.'_users'});
-		    print "</td></tr>\n";
+		    print '</td></tr>'."\n";
 		}
 	    }
-	    print "</table>";
+	    print '</table>';
 	} else {
-	    print "No active users logged in.";
+	    print &Apache::lonlocal::mt('No active users logged in.');
 	}
     } elsif ($mode eq 'load') {
 # Load
@@ -587,7 +602,7 @@ sub reports {
 '<tr><td bgcolor="#BBDDBB"><font face="arial" color="#225522" size="+1">'.
                         $local.
 			'</font><br /><font size="-2">'.
-			$domaindescription{$hostdom{$local}}.
+			$Apache::lonnet::domain{$hostdom{$local}}{'description'}.
 		       '</font></td><td bgcolor="#DDDDBB">';
 		    &server($local);
 		    print 
@@ -599,46 +614,51 @@ sub reports {
 	    }
 	    print "</table>";
 	} else {
-	    print "No workload.";
+	    print &Apache::lonlocal::mt('No workload.');
 	}
     } elsif ($mode eq 'trouble') {
 	my $count=0;
 	foreach my $local (sort keys %hostname) {
 	    my $trouble='';
 	    if ($host{$local.'_unresponsive_doomed'}>3) {
-		$trouble='Does not respond to several queries.<br />';
+		$trouble=&Apache::lonlocal::mt('Does not respond to several queries.').
+                         '<br />';
 	    }
 	    if ($host{$local.'_errors'}) {
-		$trouble='Has loncron errors.<br />';
+		$trouble=&Apache::lonlocal::mt('Has loncron errors').'<br />';
 	    } elsif ($host{$local.'_loncron_doomed'}>2500) {
-		$trouble='High loncron count.<br />';
+		$trouble=&Apache::lonlocal::mt('High loncron count.').'<br />';
 	    }
 	    if ($host{$local.'_load_doomed'}>5) {
-		$trouble='High load.<br />';
+		$trouble=&Apache::lonlocal::mt('High load.').'<br />';
 	    }
 	    if ($host{$local.'_users_doomed'}>200) {
-		$trouble='High user volume.<br />';
+		$trouble=&Apache::lonlocal::mt('High user volume.').'<br />';
 	    }
 	    if ($host{$local.'_mysql_doomed'}>1) {
-		$trouble='MySQL database apparently offline.<br />';
+		$trouble=&Apache::lonlocal::mt('MySQL database apparently offline.').'<br />';
 	    }
 	    if ($host{$local.'_checkrpms_doomed'}>100) {
-		$trouble='RPMs outdated.<br />';
+		$trouble=&Apache::lonlocal::mt('RPMs outdated.').'<br />';
 	    }
 	    if ($host{$local.'_reroute'}) {
-		$trouble='Rerouting<br >';
+		$trouble=&Apache::lonlocal::&mt('Rerouting').'<br >';
 	    }
 	    if ($trouble) { $count++; &serverstatus($local,$trouble); }
 	}
-	unless ($count) { print "No mayor trouble."; }
+	unless ($count) { print &Apache::lonlocal::mt('No major trouble.'); }
     }
 }
 
 # ====================================================================== Status
 sub statuslist {
     my ($local,$what)=@_;
-    print 
-"<script>document.prgstat.progress.value='Testing $local ($hostname{$local}): $what';</script>\n";
+    my $displaylocal;
+    if (defined($local)) {
+        $displaylocal = " $local ($hostname{$local})";
+    }
+    print '<script>document.prgstat.progress.value="'. 
+          &Apache::lonlocal::mt("Testing[_1]: $what",$displaylocal).'";</script>'."\n";
 }
 
 # =============================================================================
@@ -677,23 +697,23 @@ my $starttime=time;
 
 # ============================================================== Determine mode
 
-my %modes=('trouble' => 'Trouble',
-	   'users_doomed' => 'Doomed: Users',
-	   'loncron_doomed' => 'Doomed: General (loncron)',
-	   'mysql_doomed' => 'Doomed: Database (mysql)',
-	   'notconnected_doomed' => 'Doomed: Connections',
-	   'checkrpms_doomed' => 'Doomed: RPMs',
-	   'load_doomed' => 'Doomed: Load',
-	   'unresponsive_doomed' => 'Doomed: Status could not be determined',
-	   'users' => 'User Report',
-	   'load' => 'Load Report',
-	   'connections' => 'Connections Matrix');
-
+my %modes= &Apache::lonlocal::texthash (
+                     'trouble' => 'Trouble',
+	             'users_doomed' => 'Doomed: Users',
+	             'loncron_doomed' => 'Doomed: General (loncron)',
+	             'mysql_doomed' => 'Doomed: Database (mysql)',
+	             'notconnected_doomed' => 'Doomed: Connections',
+	             'checkrpms_doomed' => 'Doomed: RPMs',
+	             'load_doomed' => 'Doomed: Load',
+	             'unresponsive_doomed' => 'Doomed: Status could not be determined',
+	             'users' => 'User Report',
+	             'load' => 'Load Report',
+	             'connections' => 'Connections Matrix');
 $mode=$FORM{'mode'};
 unless ($modes{$mode}) { $mode='trouble'; }
 # ================================================================ Send Headers
-print "Content-type: text/html\n\n".
-    "<html><body bgcolor='#FFFFFF'>\n";
+print("Content-type: text/html\n\n".
+      '<html><body bgcolor="#FFFFFF">'."\n");
 # -------------------- Read loncapa.conf (and by default, loncapa_apache.conf).
 my $perlvarref=LONCAPA::Configuration::read_conf('loncapa.conf');
 %perlvar=%{$perlvarref};
@@ -701,72 +721,66 @@ undef $perlvarref; # remove since sensitive and not needed
 delete $perlvar{'lonReceipt'}; # remove since sensitive and not needed
 delete $perlvar{'lonSqlAccess'}; # remove since sensitive and not needed
 
-# ------------------------------------------------------------- Read hosts file
-{
-    my $config=IO::File->new("$perlvar{'lonTabDir'}/hosts.tab");
-
-    while (my $configline=<$config>) {
-       $configline=~s/#.*$//;
-       unless ($configline=~/\w/) { next; } 
-       my ($id,$domain,$role,$name,$ip)=split(/:/,$configline);
-       $hostname{$id}=$name;
-       $hostdom{$id}=$domain;
-       $hostrole{$id}=$role;
-       $hostip{$id}=$ip;
-       if (($role eq 'library') && ($id ne $perlvar{'lonHostID'})) {
-	   $libserv{$id}=$name;
-       }
-    }
+if (!&LONCAPA::loncgi::check_cookie_and_load_env()) {
+    &Apache::lonlocal::get_language_handle();
+    print(&LONCAPA::loncgi::missing_cookie_msg());
+    exit;
 }
-# ------------------------------------------------------------ Read domain file
-{
-    my $fh=IO::File->new($perlvar{'lonTabDir'}.'/domain.tab');
-    if ($fh) {
-       while (<$fh>) {
-           next if (/^(\#|\s*$)/);
-           chomp;
-           my ($domain, $domain_description, $def_auth, $def_auth_arg,
-	       $def_lang, $city, $longi, $lati) = split(/:/,$_);
-	   $domain_auth_def{$domain}=$def_auth;
-           $domain_auth_arg_def{$domain}=$def_auth_arg;
-	   $domaindescription{$domain}=$domain_description;
-	   $domain_lang_def{$domain}=$def_lang;
-	   $domain_city{$domain}=$city;
-	   $domain_longi{$domain}=$longi;
-	   $domain_lati{$domain}=$lati;
-       }
+
+if (!&LONCAPA::lonauthcgi::can_view('clusterstatus')) {
+    &Apache::lonlocal::get_language_handle();
+    print &LONCAPA::lonauthcgi::unauthorized_msg('clusterstatus');
+    exit;
+}
+
+&Apache::lonlocal::get_language_handle();
+
+my $scope = 'Domain';
+if ($Apache::lonnet::env{'request.role'} =~ m{^su\./}) {
+    %hostname = %allhostname;
+    $scope = 'Cluster';
+} else {
+    undef(%hostname);
+    my @poss_domains = &Apache::lonnet::current_machine_domains();
+    foreach my $host (keys(%allhostname)) {
+        if (grep(/^\Q$hostdom{$host}\E$/,@poss_domains)) {
+            $hostname{$host} = $allhostname{$host};
+        }
     }
 }
 
-print "<img src='/adm/lonIcons/lonlogos.gif' align='right' /><h1>LON-CAPA Cluster Status ".localtime()."</h1>";
+print '<img src="/adm/lonIcons/lonlogos.gif" align="right" /><h1>'.&Apache::lonlocal::mt("LON-CAPA $scope Status").' '.localtime()."</h1>";
 print "<form name='prgstat'>\n".
-"<input type='text' name='progress' value='Starting ...' size='100' /><br />".
-"</form>\n";;
+'<input type="text" name="progress" value="'."'".&Apache::lonlocal::mt('Starting ...')."'".'" size="100" /><br />'.
+"</form>\n";
 print "<form name='status' method='post'>\n";
-print 'Choose next report: '.&select_form($mode,'mode',%modes).'<hr />';
+print &Apache::lonlocal::mt('Choose next report:').' '.&select_form($mode,'mode',%modes).'<input type="submit" name="getreport" value="'.&Apache::lonlocal::mt('Go').'" /><hr />';
 &hidden('refresh',$refresh);
 
     if (!$FORM{'runonetime'}) {
-	print 
-   "<h3>Gathering initial cluster data</h3>This may take some time ...<br />";
+        my $lcscope = lc($scope);
+	print '<h3>'.&Apache::lonlocal::mt("Gathering initial $lcscope data").'</h3>'.
+              &Apache::lonlocal::mt('This may take some time ..').'<br />';
 	$fromcache=0;
 	&mainloop();
-	&statuslist('Done initial run.');
+	&statuslist(undef,'Done initial run.');
 	&reports();
     } else {
 	$fromcache=1;
 	&mainloop();
-	&statuslist('Done gathering cached data');
+	&statuslist(undef,'Done gathering cached data');
 	&reports();
 	$fromcache=0;
 	&mainloop();
     }
     &hidden('runonetime',1);
-print '<tt><br />Total number of queries: '.$stat_total.
-          '<br />Percent complete: '.
-	  int(($stat_total-$stat_notyet)/$stat_total*100.).
-	  '<br />Percent from cache: '.
-          int($stat_fromcache/$stat_total*100.).'</tt>';
+    print '<tt><br />'.&Apache::lonlocal::mt('Total number of queries: [_1]',$stat_total);
+    if ($stat_total != 0) {
+        print '<br />'.&Apache::lonlocal::mt('Percent complete:').''.
+	      int(($stat_total-$stat_notyet)/$stat_total*100.).
+	      '<br />'.&Apache::lonlocal::mt('Percent from cache:').' '.
+              int($stat_fromcache/$stat_total*100.).'</tt>';
+    }
 
 # ============================================================== Close, refresh
 print "</form><script>";
@@ -775,8 +789,9 @@ if (($refresh-$runtime)<0) {
     print "document.status.submit();";
 } else {
     my $refreshtime=int(1000*($refresh-$runtime));
+    my $refreshmsg = &Apache::lonlocal::mt('Will automatically refresh ([_1] secs refresh cycle)',$refresh);
     print "setTimeout('document.status.submit()',$refreshtime);\n".
-          "document.prgstat.progress.value='Will automatically refresh ($refresh secs refresh cycle)'";
+          "document.prgstat.progress.value='$refreshmsg'";
 }
 print "</script></body></html>";
 exit 0;
