@@ -1,6 +1,6 @@
 # functions to glue school database system into Lon-CAPA for 
 # automated enrollment
-# $Id: localenroll.pm,v 1.29 2008/01/03 23:28:33 raeburn Exp $
+# $Id: localenroll.pm,v 1.31 2008/02/29 21:01:43 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -648,7 +648,6 @@ sub username_rules {
 #
 # (c) $rulesorder - reference to array containing rule names
 #                   in order to be displayed
-
 #
 #  returns 'ok' if no processing error.
 #
@@ -660,6 +659,33 @@ sub id_rules {
     return $outcome;
 }
 
+###############################
+# sub selfcreate_rules
+#
+# Incoming data: three arguments
+# (a) $dom - domain
+# (b) $ruleshash - reference to hash containing rules
+#                  (a hash of a hash)
+#                  keys of top level hash are short names
+#                   (e.g., netid)
+#                  for each key, value is a hash
+#                      desc => long name for rule
+#                      rule => description of rule
+#
+# (c) $rulesorder - reference to array containing rule names
+#                   in order to be displayed
+#
+#  returns 'ok' if no processing error.
+#
+###############################
+
+
+sub selfcreate_rules {
+    my ($dom,$ruleshash,$rulesorder) = @_;
+    my $outcome;
+    return $outcome;
+}
+
 ###############################
 # sub username_check 
 #
@@ -704,6 +730,28 @@ sub id_check {
     return $outcome;
 }
 
+###############################
+# sub selfcreate_check
+#
+# Incoming data: four arguments
+# (a) $dom - domain (scalar)
+# (b) $selfcreatename - e-mail proposed as username (compare against rules - scalar)
+# (c) $to_check (reference to array of rule names to check)
+# (d) $resultshash (reference to hash of results)
+#                   hash of results for rule checked
+#                   - keys are rule names
+#                   - values are: 1 or 0 (for matched or unmatched)
+#
+# returns 'ok' if no processing error.
+#
+###############################
+
+sub selfcreate_check {
+    my ($dom,$selfcreatename,$to_check,$resultshash) = @_;
+    my $outcome;
+    return $outcome;
+}
+
 ###############################
 # sub AUTOLOAD
 #
