@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # essay (ungraded) style responses
 #
-# $Id: essayresponse.pm,v 1.96 2008/12/22 14:55:28 raeburn Exp $
+# $Id: essayresponse.pm,v 1.98 2009/01/05 05:54:34 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -294,11 +294,14 @@ sub file_submission {
                 }
             } else {
                 my ($symb,$crsid,$udom,$uname) = &Apache::lonnet::whichuser();
-                my ($path,$filename) = ($file =~ m{^(.+)/([^/]+)$});
+                my ($path,$filename) = ($file =~ m{^(.*/)([^/]+)$});
                 my $fullpath = '/userfiles/portfolio'.$path;
                 if (!exists($dirlist{$fullpath})) {
                     my @list = &Apache::lonnet::dirlist($fullpath,$udom,$uname,1);
-                    foreach my $dir_line (@list) {
+                    $dirlist{$fullpath} = \@list;
+                }
+                if (ref($dirlist{$fullpath}) eq 'ARRAY') {
+                    foreach my $dir_line (@{$dirlist{$fullpath}}) {
                         my ($fname,$dom,undef,$testdir,undef,undef,undef,undef,
                             $size,undef,$mtime,undef,undef,undef,$obs,undef) = 
                         split(/\&/,$dir_line,16);
@@ -310,7 +313,6 @@ sub file_submission {
                             last;
                         }
                     }
-                    $dirlist{$fullpath} = \@list;
                 }
             }
             if (ref($totalsize)) {
@@ -319,6 +321,7 @@ sub file_submission {
                     if ($which eq 'filename') {
                         &delete_form_items($jspart,$id);
                     }
+                    last;
                 } else {
                     push(@accepted_files,$file);
                 }
@@ -375,7 +378,7 @@ sub file_submission {
 	    $Apache::lonhomework::results{"resource.$part.$id.uploadedurl"}=
 		&Apache::lonnet::userfileupload('HWFILE'.$jspart.'_'.$id,undef,
 						$subdir);
-            &Apache::lonnet::delenv($env{'form.HWFILE'.$jspart.'_'.$id});
+            delete($env{'form.HWFILE'.$jspart.'_'.$id});
 	}
     } elsif ($which eq 'portfiles' &&
 	     $Apache::lonhomework::history{"resource.$part.$id.$which"}) {
@@ -387,9 +390,9 @@ sub file_submission {
 
 sub delete_form_items {
     my ($jspart,$id) = @_;
-    &Apache::lonnet::delenv($env{'form.HWFILE'.$jspart.'_'.$id.'.filename'});
-    &Apache::lonnet::delenv($env{'form.HWFILE'.$jspart.'_'.$id.'.mimetype'});
-    &Apache::lonnet::delenv($env{'form.HWFILE'.$jspart.'_'.$id});
+    delete($env{'form.HWFILE'.$jspart.'_'.$id.'.filename'});
+    delete($env{'form.HWFILE'.$jspart.'_'.$id.'.mimetype'});
+    delete($env{'form.HWFILE'.$jspart.'_'.$id});
 }
 
 
