@@ -2,7 +2,7 @@
 # The LearningOnline Network with CAPA
 # image click response style
 #
-# $Id: imageresponse.pm,v 1.94 2008/08/08 16:37:13 bisitz Exp $
+# $Id: imageresponse.pm,v 1.94.2.1 2008/12/21 05:22:01 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -239,7 +239,7 @@ sub displayfoils {
 	my $image=$Apache::response::foilgroup{"$name.image"};
 	&Apache::lonxml::debug("image is $image");
 	if ( ($target eq 'web' || $target eq 'answer') 
-	     && $image !~ /^http:/ ) {
+	     && $image !~ /^https?\:/ ) {
 	    $image=&clean_up_image($image);
 	}
 	push(@images,$image);
@@ -305,7 +305,7 @@ sub display_answers {
 	my $image=$Apache::response::foilgroup{"$name.image"};
 	&Apache::lonxml::debug("image is $image");
 	if ( ($target eq 'web' || $target eq 'answer')
-	     && $image !~ /^http:/ ) {
+	     && $image !~ /^https?\:/ ) {
 	    $image = &clean_up_image($image);
 	} 
 	my $token=&prep_image($image,'answeronly',$name);
@@ -320,7 +320,7 @@ sub clean_up_image {
     my ($image)=@_;
     if ($image =~ /\s*<img\s*/) {
 	($image) = ($image =~ /src\s*=\s*[\"\']([^\"\']+)[\"\']/i);
-	if ($image !~ /^http:/) {
+	if ($image !~ /^https?\:/) {
 	    $image=&Apache::lonnet::hreflocation('',$image);
 	}
 	if (!$image) {
