@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # random labelling tool
 #
-# $Id: randomlabel.pm,v 1.91 2008/03/12 02:46:53 raeburn Exp $
+# $Id: randomlabel.pm,v 1.91.2.1 2008/12/21 15:10:12 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -130,7 +130,7 @@ sub start_randomlabel {
     $label_xscale = 1.0;		# Assume image size not overridden.
     $label_yscale = 1.0;
     my $bgimg= &Apache::lonxml::get_param('bgimg',$parstack,$safeeval);
-    if ( defined($bgimg) && $bgimg !~ /^http:/ ) {
+    if ( defined($bgimg) && $bgimg !~ /^https?\:/ ) {
 	$bgimg=&Apache::lonnet::filelocation($Apache::lonxml::pwd[-1],$bgimg);
 	if (&Apache::lonnet::repcopy($bgimg) ne 'ok') {
 	    $bgimg='/home/httpd/html/adm/lonKaputt/lonlogo_broken.gif';
