@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # rank style response
 #
-# $Id: rankresponse.pm,v 1.57 2008/08/08 16:37:13 bisitz Exp $
+# $Id: rankresponse.pm,v 1.57.2.2 2008/12/18 20:04:46 raeburn Exp $
 # Copyright Michigan State University Board of Trustees
 #
 # This file is part of the LearningOnline Network with CAPA (LON-CAPA).
@@ -48,15 +48,17 @@ sub start_rankresponse {
     if ($target eq 'meta') {
 	$result=&Apache::response::meta_package_write('rankresponse');
     } elsif ($target eq 'edit' ) {
-	$result.=&Apache::edit::start_table($token).
-	    '<tr><td>'.&Apache::lonxml::description($token)."</td><td>Delete:".
-	    &Apache::edit::deletelist($target,$token)
-	    ."</td><td>&nbsp".&Apache::edit::end_row()
-	    .&Apache::edit::start_spanning_row();
+        $result.=&Apache::edit::start_table($token)
+           .'<tr><td>'.&Apache::lonxml::description($token).'</td>'
+           .'<td><span class="LC_nobreak">'.&mt('Delete?').' '
+           .&Apache::edit::deletelist($target,$token)
+           .'</span></td>'
+           .'<td>&nbsp;'.&Apache::edit::end_row()
+           .&Apache::edit::start_spanning_row();
 	
 	$result.=
 	    &Apache::edit::text_arg('Max Number Of Shown Foils:','max',$token,'4').
-	    &Apache::edit::select_arg('Randomize Foil Order','randomize',
+	    &Apache::edit::select_arg('Randomize Foil Order:','randomize',
 				      ['yes','no'],$token).
 	    &Apache::edit::end_row().&Apache::edit::start_spanning_row()."\n";
     } elsif ($target eq 'modified') {
