@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Communicate
 #
-# $Id: loncommunicate.pm,v 1.40 2006/12/23 06:58:17 raeburn Exp $
+# $Id: loncommunicate.pm,v 1.41 2007/01/31 16:02:49 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -55,8 +55,6 @@ sub menu {
      'User Notes, Records of Face-to-Face Discussions, and Critical Messages',
 
 'cbs' => "Configure Blocking of $usertype Communication during Exams",
-'blog' => 'Add or Edit Blog Entries' 
-
 );
     my %help=();
     foreach ('Course_Face_To_Face_Records,Course_Critical_Message',
@@ -88,9 +86,7 @@ sub menu {
 <td bgcolor="#FFFFAA">
   <b><a href="/adm/email?compose=individual">$lt{'smu'}</a></b>
 </td>
-<td bgcolor="#FFFFAA">
-  <b><a href="/adm/$env{'user.domain'}/$env{'user.name'}/_rss.html">$lt{'blog'}</a></b>
-</td>
+<td></td>
 </tr>
 END
     if ($can_srm) {
