@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines to control the menu
 #
-# $Id: lonmenu.pm,v 1.239.4.2 2008/12/13 15:55:40 raeburn Exp $
+# $Id: lonmenu.pm,v 1.239.4.3 2008/12/30 18:39:03 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -514,8 +514,18 @@ c&8&1
 c&8&2
 s&8&3&prt.gif&prepare[_1]&printout[_1]&gopost('/adm/printout',currentURL)&Prepare a printable document
 s&9&1&sbkm.gif&set[_1]&bookmark[_2]&set_bookmark()&Set a bookmark for this resource&&1
-s&9&3&anot.gif&anno-[_1]&tations[_1]&annotate()&Make notes and annotations about this resource&&1
 ENDMENUITEMS
+            my $currentURL = &Apache::loncommon::get_symb();
+            my ($symb_old,$symb_old_enc) = &Apache::loncommon::clean_symb($currentURL);
+            my $annotation = &Apache::loncommon::get_annotation($symb_old,$symb_old_enc);
+            $menuitems.="s&9&3&";
+            if (length($annotation) > 0){
+                $menuitems.="anot2.gif";
+            } else {
+                $menuitems.="anot.gif";
+            }
+            $menuitems.="&anno-[_1]&tations[_1]&annotate()&";
+            $menuitems.="Make notes and annotations about this resource&&1\n";
 
             unless ($env{'request.noversionuri'}=~/\/(bulletinboard|smppg|navmaps|syllabus|aboutme)(\?|$)/) {
 		if (!$env{'request.enc'}) {
