@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a course
 #
-# $Id: lonpickcourse.pm,v 1.73.2.4 2008/09/21 16:41:47 raeburn Exp $
+# $Id: lonpickcourse.pm,v 1.75.2.1 2008/12/14 04:29:15 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -228,23 +228,19 @@ sub display_matched_courses {
                  $menuchk = ' checked="checked" ';
             }
             $r->print(
-                '<table class="LC_pick_box">'.
-                '<tr class="LC_pick_box_row">'.
-                '<td class="LC_pick_box_title" rowspan="2">'.&mt('Action').'</td>'.
-                '<td class="LC_evenrow_value">'.
-                '<span class="LC_nobreak"><label>'.
-                '<input type="radio" name="phase" value="ccrole"'.$ccrolechk.'/>'.
-                '&nbsp;'.&mt('Enter the course with the role of [_1].',$cctitle).
-                '</label>'.('&nbsp;'x3).'</span>'.
-                '</td></tr>'.
-                '<tr class="LC_pick_box_row">'.
-                '<td class="LC_oddrow_value">'.
-                '<span class="LC_nobreak"><label>'.
-                '<input type="radio" name="phase" value="menu"'.$menuchk.'/>&nbsp;'.
-                &mt('View or modify course settings which only a [_1] may modify.',$dctitle).
-                '</label></span>'.
-                '</td></tr></table>'.
-                '<br />');
+                '<fieldset>'
+               .'<legend>'.&mt('Action').'</legend>'
+               .'<div class="LC_nobreak"><label>'
+               .'<input type="radio" name="phase" value="ccrole"'.$ccrolechk.'/>'
+               .'&nbsp;'.&mt('Enter the course with the role of [_1].',$cctitle)
+               .'</label></div>'
+               .'<div class="LC_nobreak"><label>'
+               .'<input type="radio" name="phase" value="menu"'.$menuchk.'/>&nbsp;'
+               .&mt('View or modify course settings which only a [_1] may modify.',$dctitle)
+               .'</label></div>'
+               .'</fieldset>'
+               .'<br />'
+            );
         }
     }
     my %by_descrip;
@@ -277,7 +273,7 @@ sub display_matched_courses {
                  .'<th>'.&mt('Domain').'</th>'
                  .'<th>'.&mt('Course Code').'</th>'
                  .'<th>'.&mt('Owner/Co-owner(s)').'</th>'
-#                 .'<th>'.&mt('Type').'</th>'
+                 .'<th>'.&mt('Type').'</th>'
                  );
         $r->print(&Apache::loncommon::end_data_table_header_row());
     }
@@ -318,13 +314,13 @@ sub display_matched_courses {
             }
             $r->print('</td>');
             $r->print('<td>'.$ownerstr.'</td>');
-#            $r->print('<td>');
-#            if ($ttype ne '') {
-#                $r->print(&mt(&unescape($ttype)));
-#            } else {
-#                $r->print('&nbsp;');
-#            }
-#            $r->print('</td>');
+            $r->print('<td>');
+            if ($ttype ne '') {
+                $r->print(&mt(&unescape($ttype)));
+            } else {
+                $r->print('&nbsp;');
+            }
+            $r->print('</td>');
             if ($multiple) { $r->print("</label>\n"); }
             $r->print(&Apache::loncommon::end_data_table_row());
             # $r->print("<br />\n");
@@ -481,34 +477,50 @@ $multelement
             $output .= '<input type="hidden" name="setroles" value="'.$env{'form.setroles'}.'" />';
         }
     }
+
+    $output .= "<br />\n".&Apache::lonhtmlcommon::start_pick_box();
     if ($sincefilterform) { 
-        $output .= $lt{'cac'}.': '.$sincefilterform.'<br />'."\n";
+        $output .= &Apache::lonhtmlcommon::row_title($lt{'cac'})
+                  .$sincefilterform
+                  .&Apache::lonhtmlcommon::row_closure();
     }
     if ($domainselectform) {
-        $output .= $lt{'cdo'}.': '.$domainselectform.'<br />'."\n";
+        $output .= &Apache::lonhtmlcommon::row_title($lt{'cdo'})
+                  .$domainselectform
+                  .&Apache::lonhtmlcommon::row_closure();
     }
 #    if ($typeselectform) {
-#        $output .= $lt{'cog'}.': '.$typeselectform.'<br />'."\n";
+#        $output .= &Apache::lonhtmlcommon::row_title($lt{'cog'})
+#                  .$typeselectform
+#                  .&Apache::lonhtmlcommon::row_closure();
 #    }
     if ($instcodeform) {
-        $output .= $lt{'cin'}.': '.$instcodeform.'<br />'."\n";
+        $output .= &Apache::lonhtmlcommon::row_title($lt{'cin'})
+                  .$instcodeform
+                  .&Apache::lonhtmlcommon::row_closure();
     }
     if (exists($filter->{'ownerfilter'})) {
-        $output .= $lt{'cow'}.': '.
-                   '<input type="text" name="ownerfilter" size="10" value="'.
-                   $list->{'ownerfilter'}.'" /><br />'."\n".
-                   $lt{'cod'}.': '.$ownerdomselectform.'<br />'."\n";
+        $output .= &Apache::lonhtmlcommon::row_title($lt{'cow'})
+                  .'<input type="text" name="ownerfilter" size="10" value="'
+                  .$list->{'ownerfilter'}.'" />'
+                  .&Apache::lonhtmlcommon::row_closure()
+                  .&Apache::lonhtmlcommon::row_title($lt{'cod'})
+                  .$ownerdomselectform
+                  .&Apache::lonhtmlcommon::row_closure();
     }
     if (exists($filter->{'coursefilter'})) {
-        $output .= &mt('LON-CAPA course ID').': '.
-                   '<input type="text" name="coursefilter" size="25" value="'.
-                    $list->{'coursefilter'}.'" /><br />';
+        $output .= &Apache::lonhtmlcommon::row_title(&mt('LON-CAPA course ID'))
+                  .'<input type="text" name="coursefilter" size="25" value="'
+                  .$list->{'coursefilter'}.'" />'
+                  .&Apache::lonhtmlcommon::row_closure();
     }
     if (exists($filter->{'descriptfilter'})) {
-        $output .=$lt{'cde'}.': '.
-                  '<input type="text" name="descriptfilter" size="40" value="'.
-                  $list->{'descriptfilter'}.'" />'."\n";
+        $output .= &Apache::lonhtmlcommon::row_title($lt{'cde'})
+                  .'<input type="text" name="descriptfilter" size="40" value="'
+                  .$list->{'descriptfilter'}.'" />'
+                  .&Apache::lonhtmlcommon::row_closure(1);
     }
+    $output .= &Apache::lonhtmlcommon::end_pick_box();
     $output .= '<p><input type="submit" name="gosearch" value="'. 
                &mt('Search').'" /></p>'."\n".'</form>'."\n".'<hr />'."\n";
     return $output; 
