@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Preferences
 #
-# $Id: lonpreferences.pm,v 1.125 2008/07/18 12:36:11 raeburn Exp $
+# $Id: lonpreferences.pm,v 1.125.2.2 2008/12/23 19:28:07 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -179,6 +179,7 @@ sub verify_and_change_languages {
         &Apache::lonnet::delenv('environment\.languages');
         $message=&mt('Reset preferred language.');
     }
+    &Apache::loncommon::flush_langs_cache($user,$domain);
     $r->print(<<ENDVCSCREEN);
 $message
 ENDVCSCREEN
@@ -1782,13 +1783,14 @@ sub handler {
                             text => 'Change Message Forwarding/Notification'},
                       printmenu => 'no',
                       subroutine => \&verify_and_change_msgforward }));
-    my $aboutmeaction=
-        '/adm/'.$env{'user.domain'}.'/'.$env{'user.name'}.'/aboutme';
-    push (@Options,{ action => 'none', 
-                     linktext =>
-                         q{Edit the 'About Me' Personal Information Screen},
-		     help => 'Prefs_About_Me',
-                     href => $aboutmeaction});
+    if (&Apache::lonnet::usertools_access($user,$domain,'aboutme')) {
+        my $aboutmeaction = '/adm/'.$domain.'/'.$user.'/aboutme';
+        push (@Options,{ action => 'none', 
+                         linktext =>
+                             q{Edit the 'About Me' Personal Information Screen},
+	   	         help => 'Prefs_About_Me',
+                         href => $aboutmeaction});
+    }
     push (@Options,({ action => 'changecolors',
                       linktext => 'Change Color Scheme',
                       href => '/adm/preferences',
