@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Souce Code handler
 #
-# $Id: lonsource.pm,v 1.20 2007/08/28 22:46:32 albertel Exp $
+# $Id: lonsource.pm,v 1.21 2008/08/01 16:01:44 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -52,15 +52,18 @@ sub make_link {
 sub stage_2 {
     my ($r, $filename, $author, $listname) = @_;
     my ($uname, $udom) = &Apache::loncacc::constructaccess('/~'.$author.'/',$r->dir_config('lonDefDomain'));
-    $r->print(&Apache::loncommon::start_page('Problem source code moving operation'));
-    $r->print("Please enter the directory that you would like the source code to go into, a default has also been 			provided <br />");
-    $r->print("Also note, the path is in reference to the root of your construction space, and new directories will be 			automatically created. <br /><br />");
+    $r->print(&Apache::loncommon::start_page('Copy Problem Source Code to Construction Space')
+             .&mt('Please enter the directory that you would like the source code to go into.')
+             .'<p>'
+             .&mt('Note: the path is in reference to the root of your construction space,'
+                 .' and new directories will be automatically created.')
+             .'</p>');
     $r->print('<form name="copy" action="/adm/source" target="_parent" method="post">
               <input type="hidden" name="filename" value="'.$filename.'" />
               <input type="hidden" name="listname" value="'.$listname.'" />
               <input type="hidden" name="action" value="copy_stage" />
-              <input type="text" size="50" name="newpath" value="/shared_source/'.$author.'" />&nbsp;
-              <input type="submit" value="Copy" />
+              <input type="text" size="50" name="newpath" value="/'.&mt('shared_source').'/'.$author.'" />&nbsp;
+              <input type="submit" value="'.&mt('Copy').'" />
               </form>');
     return OK;
 }
@@ -250,11 +253,11 @@ sub handler {
         &delete_copy_file($r, $env{'form.author'}, $env{'form.newpath'}, $env{'form.filename'}, $env{'form.path'}, '0');
     } else {
 	$r->print('<form name="copy" action="/adm/source" target="_parent" method="post">
-                  <input type="button" value="Close Window" name="close" onClick="window.close()" />
+                  <input type="button" value="'.&mt('Close Window').'" name="close" onClick="window.close()" />
                   <input type="hidden" name="filename" value="'.$filename.'" />
                   <input type="hidden" name="listname" value="'.$listname.'" />
                   <input type="hidden" name="action" value="stage2" />
-                  <input type="submit" value="Copy to CSTR" />
+                  <input type="submit" value="'.&mt('Copy to Construction Space').'" />
                   </form>');
         $r->print('<hr />');
         &print_item($r, $env{'form.filename'});
