@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lontrackstudent.pm,v 1.25 2008/12/20 04:31:55 raeburn Exp $
+# $Id: lontrackstudent.pm,v 1.26 2009/01/02 23:07:55 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -48,6 +48,7 @@ use Apache::lonmysql;
 use Apache::lonnet;
 use Apache::lonlocal;
 use Time::HiRes;
+use DateTime();
 use lib '/home/httpd/lib/perl/';
 use LONCAPA;
 
@@ -265,6 +266,7 @@ sub output_results {
     if ($mode eq 'full_class') { 
         $tableheader = 
             '<table><tr>'.
+            '<th>&nbsp;</th>'.
             '<th>'.&mt('Resource').'</th>'.
             '<th>'.&mt('Time').'</th>'.
             '<th>'.&mt('Student').'</th>'.
@@ -275,6 +277,7 @@ sub output_results {
     } elsif ($mode =~ /^student:(.*):(.*)$/) {
         $tableheader = 
             '<table><tr>'.
+            '<th>&nbsp;</th>'.
             '<th>'.&mt('Resource').'</th>'.
             '<th>'.&mt('Time').'</th>'.
             '<th>'.&mt('Action').'</th>'.
@@ -286,6 +289,17 @@ sub output_results {
     $r->rflush();
     ##
     ##
+
+    my $cid = $env{'request.course.id'};
+    my $cnum = $env{'course.'.$cid.'.num'};
+    my $cdom = $env{'course.'.$cid.'.domain'};   
+    my $server_timezone = &Apache::lonnet::get_server_timezone($cnum,$cdom);
+    if ($server_timezone ne '') {
+        if (&Apache::lonlocal::gettimezone($server_timezone) eq 'local') {
+            $server_timezone = '';
+        }
+    }
+
     while (my $line = <ACTIVITYDATA>) {
         # FIXME: does not pass symbs along :(
         chomp($line);
@@ -367,6 +381,9 @@ sub output_results {
                 '<a href="'.$src.'">'.$title.'</a>'.
                 '</span></td>';
         }
+        if ($server_timezone ne '') {
+            $timestamp = &convert_timezone($server_timezone,$timestamp);
+        }
         $tablerow .= '<td valign="top"><span class="LC_nobreak">'.$timestamp.'</span></td>';
         if ($mode eq 'full_class') {
             $tablerow.='<td valign="top">'.$student.'</td>';
@@ -383,6 +400,30 @@ sub output_results {
     return $count;
 }
 
+sub convert_timezone {
+    my ($server_timezone,$timestamp) = @_;
+    if ($server_timezone && $timestamp) {
+        my ($date,$time) = split(/\s+/,$timestamp);
+        my ($year,$month,$day) = split(/\-/,$date);
+        my ($hour,$minute,$sec) = split(/:/,$time);
+        foreach ($month,$day,$hour,$minute,$sec) {
+            return $timestamp if $_ eq '';
+            $_ =~ s/^0//;
+        }
+        my $dt = DateTime->new(year      => $year,
+                               month     => $month,
+                               day       => $day,
+                               hour      => $hour,
+                               minute    => $minute,
+                               second    => $sec,
+                               time_zone => $server_timezone,
+                              );
+        my $unixtime = $dt->epoch;
+        $timestamp = &Apache::lonlocal::locallocaltime($unixtime);
+    }
+    return $timestamp;
+}
+
 ###################################################################
 ###################################################################
 sub display_values {
