@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 # CGI-script to run LaTeX, dvips, ps2ps, ps2pdf etc.
 #
-# $Id: printout.pl,v 1.135 2008/03/26 09:50:21 foxr Exp $
+# $Id: printout.pl,v 1.137 2008/08/27 01:38:10 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -264,7 +264,7 @@ my $ind=-1;
 
 my %prog_state;
 if ($advanced_role) { 
-    %prog_state=&Apache::lonhtmlcommon::Create_PrgWin('','Print Status','Class Print Status',$number_of_files,'inline','80'); 
+    %prog_state=&Apache::lonhtmlcommon::Create_PrgWin('','Print Status',&mt('Class Print Status'),$number_of_files,'inline','80'); 
 }
 print "<br />";
 my $num_files = @texfile;	# How does this differ from $number_of_files , can that be 0?
@@ -594,7 +594,7 @@ sub busy_wait_command {
 # various bits and pieces that control how the latex file is processed:
 # LaTeX is run as many times a needed to make this all happen... this may
 # result in several runs of LaTeX that just are errors if the LaTeX is
-# bad, butthe printing subsystem is _supposed_ to not do that.
+# bad, but the printing subsystem is _supposed_ to not do that.
 #
 # Parameters:
 #   name_file        - Name of the LaTeX file to process.
@@ -966,16 +966,20 @@ sub analyze_logfile {
 				      length($badtext) - $whereitbegins - 48);
 		# print "<br />failing resourcename: $badresource<br />";
 	    }
-	}
+        }
 
 	# Guys with privileged roles get a more detailed error output:
 
 	if ($advanced_role) {  
 	    #LaTeX failed to parse tex file 
-	    print "<h2>LaTeX could not successfully parse your tex file.</h2>";
-	    print "It probably has errors in it.<br />";
-	    print "With very high probability this error occured in ".$badtext."<br /><br />";
-	    print "Here are the error messages in the LaTeX log file<br /><pre>";
+	    print "<h2>".&mt('LaTeX could not successfully parse your tex file.')."</h2>";
+	    print &mt('It probably has errors in it.')."<br />";
+	    if ($badtext) {
+                print &mt('With very high probability this error occured in [_1].',$badtext)
+                     ."<br /><br />";
+            }
+	    print &mt('Here are the error messages in the LaTeX log file:')
+                 ."<br /><pre>";
 	    
 	    my $sygnal = 0;
 	    for (my $i=0;$i<=$#content_of_file;$i++) {
@@ -991,10 +995,10 @@ sub analyze_logfile {
 	    }
 	    print "</pre>\n";
 	    # print "<br /> Advanced role <br />";
-	    print "<b><big>The link to ";
 	    $logfilename=~s{^\Q$perlvar{'lonPrtDir'}\E}{/prtspool};
-	    print "<a href=\"$logfilename\">Your log file </a></big></b>";
-	    print "\n";
+	    print "<b><big>"
+                 .&mt('The link to [_1]Your log file[_2]','<a href="'.$logfilename.'">','</a>')
+	         ."</big></b>\n";
 	    #link to original LaTeX file
 	    my $tex_temporary_file=IO::File->new($texfile) || die "Couldn't open tex file $texfile for reading: $!\n";
 	    my @tex_content_of_file = <$tex_temporary_file>;
@@ -1004,11 +1008,11 @@ sub analyze_logfile {
 	    $tex_temporary_file = IO::File->new('>'.$texfile); 
 	    print $tex_temporary_file '<html><head><title>LOGFILE</title></head><body><pre>'.$body_tex_file.'</pre></body></html>'."\n";
 	    print "<br /><br />";
-	    print "<b><big>The link to ";
 	    $texfile=~s{^\Q$perlvar{'lonPrtDir'}\E}{/prtspool};
-	    print "<a href=\"$texfile\">Your original LaTeX file </a></big></b>";
-	    print "\n";
-	    my $help_text = &Apache::loncommon::help_open_topic("Print_Resource", "Help on printing");
+	    print "<b><big>"
+                 .&mt('The link to [_1]Your original LaTeX file[_2]','<a href="'.$texfile.'">','</a>')
+	         ."</big></b><br /><br />\n";
+	    my $help_text = &Apache::loncommon::help_open_topic("Print_Resource", &mt('Help on printing'));
 	    print ("$help_text");
 
 	    # Students on the other hand get a minimal error message, since they won't
@@ -1021,13 +1025,20 @@ sub analyze_logfile {
 	    #    $name_file     - is the name of the LaTeX file.
 	    #    $identifier    - is the unique LaTeX identifier.l
 	    
-	    print "<br />There are errors in $badtext";
-	    print "<br />These errors prevent this resource from printing correctly";
+            print "<br />";
+	    if ($badtext) {
+                print &mt('There are errors in [_1].',$badtext);
+            } else {
+                print &mt('There are errors.');
+            }
+	    print "<br />".&mt('These errors prevent this resource from printing correctly.');
 	    my $tex_handle = IO::File->new($texfile);
 	    my @tex_contents = <$tex_handle>;
 	    &send_error_mail($identifier, $badresource, $body_log_file, \@tex_contents);
-	    print "<br />A message has been sent to the instructor describing this failure<br />";
-	    my $help_text = &Apache::loncommon::help_open_topic("Print_Resource", "Help on printing");
+	    print "<p>"
+                 .&mt('A message has been sent to the instructor describing this failure.')
+                 ."</p>";
+	    my $help_text = &Apache::loncommon::help_open_topic("Print_Resource", &mt('Help on printing'));
 	    print  ("$help_text");
 	    
 	  }
@@ -1044,22 +1055,24 @@ sub analyze_logfile {
 
     } elsif ($body_log_file=~m/<inserted text>/) {
 	my $whereitbegins = index $body_log_file,'<inserted text>';
-	print "You are running LaTeX in <b>batch mode</b>.";
+	print &mt('You are running LaTeX in [_1]batch mode[_2].','<b>','</b>');
 	while ($whereitbegins != -1) {
 	    my $tempobegin=$whereitbegins;
 	    $whereitbegins = rindex $body_log_file,'STAMPOFPASSEDRESOURCESTART',$whereitbegins;
 	    my $whereitends = index $body_log_file,'STAMPOFPASSEDRESOURCEEND',$whereitbegins;
-	    print "<br />It has found an error in".substr($body_log_file,$whereitbegins+26,$whereitends-$whereitbegins-26)." <br /> and corrected it.\n";
-	    print "Usually this correction is valid but you probably need to check the indicated resource one more time and implement neccessary corrections by yourself.\n";
+	    print "<br />"
+                 .&mt('It has found an error in [_1][_2]and corrected it.',substr($body_log_file,$whereitbegins+26,$whereitends-$whereitbegins-26),"<br />")."\n";
+	    print &mt('Usually this correction is valid but you probably need to check the indicated resource one more time and implement neccessary corrections by yourself.')."\n";
 	    $whereitbegins = index $body_log_file,'<inserted text>',$tempobegin+10;
 	}
 
 	if ($advanced_role) {  
 	    print "<br /><br />";
-	    print "<b><big>The link to ";
 	    $logfilename=~s{^\Q$perlvar{'lonPrtDir'}\E}{/prtspool};
-	    print "<a href=\"$logfilename\">Your log file </a></big></b>";
-	    print "\n";
+	    print "<b><big>"
+                 .&mt('The link to [_1]Your log file[_2]'
+                     ,'<a href="'.$logfilename.'">','</a>')
+	         ."</big></b>\n";
 	    #link to original LaTeX file
 	    my $tex_temporary_file=IO::File->new($texfile) || die "Couldn't open tex file $texfile for reading: $!\n";
 	    my @tex_content_of_file = <$tex_temporary_file>;
@@ -1069,10 +1082,10 @@ sub analyze_logfile {
 	    $tex_temporary_file = IO::File->new('>'.$texfile); 
 	    print $tex_temporary_file '<html><head><title>LOGFILE</title></head><body><pre>'.$body_tex_file.'</pre></body></html>'."\n";
 	    print "<br /><br />";
-	    print "<b><big>The link to ";
 	    $texfile=~s{^\Q$perlvar{'lonPrtDir'}\E}{/prtspool};
-	    print "<a href=\"$texfile\">Your original LaTeX file </a></big></b>";
-	    print "\n";
+	    print "<b><big>"
+                  .&mt('The link to [_1]Your original LaTeX file[_2]','<a href="'.$texfile.'">','</a>');
+	    print "</big></b>\n";
 	}
 	return 1;
     }
