@@ -1,5 +1,5 @@
 #
-# $Id: studentcalc.pm,v 1.42 2006/12/21 02:54:19 albertel Exp $
+# $Id: studentcalc.pm,v 1.43 2007/07/06 19:50:00 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -59,7 +59,6 @@ use Apache::assesscalc();
 use HTML::Entities();
 use Time::HiRes;
 use Apache::lonlocal;
-use lib '/home/httpd/lib/perl/';
 use LONCAPA;
  
 
@@ -102,7 +101,7 @@ sub initialize_sequence_cache {
     my @all_sequences = $navmap->retrieveResources(undef,
                                                sub { shift->is_map(); },1,0,1);
     for my $sequence ($navmap->getById('0.0'), @all_sequences) {
-	if ($navmap->hasResource($sequence,sub { shift->is_problem(); }, 0)){
+	if ($navmap->hasResource($sequence,sub { shift->is_problem(); }, 0,1)){
             push(@Sequences,$sequence);
 	    &get_resources($sequence);
         }
@@ -118,7 +117,7 @@ sub get_resources {
     return () if (! defined($navmap) || ! ref($navmap));
     my @resources = $navmap->retrieveResources($seq,
                                                sub { shift->is_problem(); },
-                                               0,0,0);
+                                               0,0,1);
     $res_memoize{$seq->symb()}=\@resources;
     return @resources;
 }
