@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonsurveyreports.pm,v 1.16 2008/09/14 15:16:30 raeburn Exp $
+# $Id: lonsurveyreports.pm,v 1.22 2008/12/12 05:03:39 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -73,7 +73,7 @@ sub BuildSurveyReportsPage {
     my @Students = @Apache::lonstatistics::Students;
     #
     if (@Students < 1) {
-        $r->print('<h2>There are no students in the sections selected</h2>');
+        $r->print('<p class="LC_warning">'.&mt('There are no students in the sections selected.').'</p>');
     }
     #
     my @CacheButtonHTML = 
@@ -133,7 +133,10 @@ sub BuildSurveyReportsPage {
             $r->print('<h1>'.$resource->compTitle.'</h1>');
             $r->print('<h3>'.$resource->src.'</h3>');
             if ($env{'form.renderprob'} eq 'true') {
-                $r->print(&Apache::lonstathelpers::render_resource($resource));
+                $r->print('<hr />'
+                         .&Apache::lonstathelpers::render_resource($resource)
+                         .'<hr />'
+                );
             }
             $r->rflush();
             my %Data = &Apache::lonstathelpers::get_problem_data
@@ -182,9 +185,9 @@ sub SurveyProblemSelector {
         }
     }
     if (! scalar(@SurveyProblems)) {
-        $Str = '<h1>'.
-            &mt('There are no survey problems in this course').
-            '</h1>'.$/;
+        $Str = '<p class="LC_warning">'.
+            &mt('There are no survey problems in this course.').
+            '</p>'.$/;
         return $Str;
     }
     $Str .= '<table>'.$/;
@@ -201,17 +204,17 @@ sub SurveyProblemSelector {
               resptype=>undef});
         my $checked = '';
         if ($env{'form.problemchoice'} eq $value) {
-            $checked = 'checked ';
+            $checked = 'checked="checked" ';
         }
         my $link = $problem->{'res'}->link.
             '?symb='.&escape($problem->{'res'}->shown_symb);
         $Str .= '<tr><td>'.
             '<input type="radio" name="problemchoice" id="'.$id.'" '.
                    'value="'.$value.'" '.$checked.'/>'.'</td>'.
-            '<td><nobr>'.
-            '<label for="'.$id.'">'.$problem->{'res'}->compTitle.'('.$problem->{'seq'}->compTitle.')'.'</label>'.
+            '<td><span class="LC_nobreak">'.
+            '<label for="'.$id.'">'.$problem->{'res'}->compTitle.' ('.$problem->{'seq'}->compTitle.')'.'</label>'.
             ('&nbsp;'x2).
-            qq{<a target="preview" href="$link">view</a>}.'</td></tr>'.$/;
+            '<a target="preview" href="'.$link.'">'.&mt('View survey').'</a></span></td></tr>'.$/;
     }
     $Str .= '</table>';
     return $Str;
@@ -326,16 +329,17 @@ sub make_text_report {
     }
     close($file);
     if($something_has_been_output) {
-        $r->print('<p><a href="'.$filename.'">'.
-                  &mt('Your text file.').
+        $r->print('<p class="LC_info"><a href="'.$filename.'">'.
+                  &mt('Your text file').
                   '</a></p>'."\n");
         $r->print('<script>'.
                   'window.document.Statistics.stats_status.value="'.
-               &mt('Done compiling text file.  See link below to download.').
+               &mt('Done compiling text file. See link below to download.').
                   '";</script>');
     } else {
-        $r->print('<h2>'.
-                  &mt("There is no essay or string response data to output for this survey.").'</h2>');
+        $r->print('<p class="LC_warning">'
+                 .&mt('There is no essay or string response data to output for this survey.')
+                 .'</p>');
     }
     $r->rflush();
     return;
@@ -386,8 +390,8 @@ sub make_Excel_report {
                 my $warned_about_size = 0;
                 foreach my $data (@{$data->{'responses'}}) {
                     if (length($data) > 255 && ! $warned_about_size) {
-                        $r->print('<p>'.
-                                  &mt('[_1]:[_2] responses to  [_3] may be too long to fit Excel spreadsheet.',
+                        $r->print('<p class="LC_warning">'.
+                                  &mt('[_1]:[_2] responses to [_3] may be too long to fit Excel spreadsheet.',
                                       $resource->compTitle,
                                       $resource->part_display($partid),
                                       $respid).
@@ -447,12 +451,12 @@ sub make_Excel_report {
         }    #response ids
     }    # partids
     $workbook->close();
-    $r->print('<p><a href="'.$filename.'">'.
+    $r->print('<p class="LC_info"><a href="'.$filename.'">'.
               &mt('Your Excel spreadsheet.').
               '</a></p>'."\n");
     $r->print('<script>'.
               'window.document.Statistics.stats_status.value="'.
-              &mt('Done compiling spreadsheet.  See link below to download.').
+              &mt('Done compiling spreadsheet. See link below to download.').
               '";</script>');
     $r->rflush();
     return;
@@ -506,14 +510,17 @@ sub make_HTML_report {
                 }
             } elsif (exists($data->{'foil_count'}) && 
                      exists($data->{'foil_responses'})) {
-                $Str.='<tr><td colspan="3">'.
-                    '<table><tr>';
+                $Str.='<tr>'
+                    .'<td colspan="3">'
+                    .&Apache::loncommon::start_data_table()
+                    .&Apache::loncommon::start_data_table_header_row();
                 my $tmp = '<th>'.join('</th><th>',
                                       (&mt('Foil Name'),
                                        &mt('Foil Text'),
                                        &mt('Option'),
                                        &mt('Frequency'),
-                                       &mt('Percent'))).'</th></tr>';
+                                       &mt('Percent'))).'</th>'
+                          .&Apache::loncommon::end_data_table_header_row();
 		my @foils = sort(keys(%{$ProblemData->{$partid.'.'.$respid}->{'_Foils'}}));
                 foreach my $foilid (@foils) {
                     my $prob_data = $ProblemData->{$partid.'.'.$respid};
@@ -521,7 +528,7 @@ sub make_HTML_report {
                     my $foiltext = $prob_data->{'_Foils'}->{$foilid}->{'text'};
                     my $foilname = $prob_data->{'_Foils'}->{$foilid}->{'name'};
                     my $rowspan = scalar(@{$prob_data->{'_Options'}});
-                    my $preamble = '<tr>'.
+                    my $preamble = &Apache::loncommon::start_data_table_row().
                         '<td valign="top" rowspan="'.$rowspan.'">'.
                             $foilname.'</td>'.
                         '<td valign="top" rowspan="'.$rowspan.'">'.
@@ -534,11 +541,12 @@ sub make_HTML_report {
                             '<td align="right">'.$count.'</td>'.
                             '<td align="right">'.
                                 sprintf('%.2f',100*$count/$foil_count).'%'.
-                            '</td></tr>'.$/;
-                        $preamble = '<tr>';
+                            '</td>'.&Apache::loncommon::end_data_table_row().$/;
+                        $preamble = &Apache::loncommon::continue_data_table_row(); #&Apache::loncommon::start_data_table_row();
                     }
                 }
-                $Str.=$tmp.'</table></td></tr>';
+                $Str.=$tmp.&Apache::loncommon::end_data_table()
+                     .'</td></tr>';
             } elsif (exists($data->{'_count'})      && 
                      exists($data->{'foil_values'}) && 
                      exists($data->{'map'})) {
@@ -553,23 +561,28 @@ sub make_HTML_report {
                     my $count = $data->{'foil_values'}->{$value};
                     my $foiltext = $ProblemData->{$partid.'.'.$respid}->{'_Foils'}->{$foilid}->{'text'};
                     my $foilname = $ProblemData->{$partid.'.'.$respid}->{'_Foils'}->{$foilid}->{'name'};
-                    $tmp .= '<tr>'.
+                    $tmp .= &Apache::loncommon::start_data_table_row().
                         '<td>'.$foilname.'</td>'.
                         '<td>'.$foiltext.'</td>'.
                         '<td align="right">'.$count.'</td>'.
                         '<td align="right">'.
                             sprintf("%.2f",$count/$total*100).'%</td>'.
-                        '</tr>'.$/;
+                        &Apache::loncommon::end_data_table_row().$/;
                 }
-                $Str .= '<tr>'.
-                    '<th>'.&mt('Foil Name').'</th>'.
-                    '<th>'.&mt('Text').'</th>'.
-                    '<th>'.&mt('Freq').'</th>'.
-                    '<th>'.&mt('Percent').'</th>'.
-                    '</tr>'.$/.
-                    $tmp;
+                $Str.='<tr>'
+                     .'<td colspan="3">'
+                     .&Apache::loncommon::start_data_table()
+                     .&Apache::loncommon::start_data_table_header_row()
+                     .'<th>'.&mt('Foil Name').'</th>'
+                     .'<th>'.&mt('Text').'</th>'
+                     .'<th>'.&mt('Frequency').'</th>'
+                     .'<th>'.&mt('Percent').'</th>'
+                     .&Apache::loncommon::end_data_table_header_row().$/
+                     .$tmp
+                     .&Apache::loncommon::end_data_table()
+                     .'</td></tr>';
             }
-            $Str.= '</table><hr />';
+            $Str.= '</table>';
             $r->print($Str);
             $r->rflush();
         }
@@ -608,23 +621,24 @@ sub CreateInterface {
                                 ) {
         $output_selector.='<option value="'.$output_format->{'name'}.'"';
         if ($env{'form.output'} eq $output_format->{'name'}) {
-            $output_selector.=' selected';
+            $output_selector.=' selected="selected"';
         }
         $output_selector.= '>'.$output_format->{'text'}.'</option>'.$/;
     }
     $output_selector .= '</select>'.$/;
     $Str .= &Apache::lonhtmlcommon::breadcrumbs('Student Submission Reports');
     $Str .= '<p>';
-    $Str .= '<table cellspacing="5">'."\n";
-    $Str .= '<tr>';
+    $Str .= &Apache::loncommon::start_data_table();
+    $Str .= &Apache::loncommon::start_data_table_header_row();
     $Str .= '<th>'.&mt('Sections').'</th>';
     $Str .= '<th>'.&mt('Groups').'</th>';
     $Str .= '<th>'.&mt('Access Status').'</th>';
     $Str .= '<th>'.&mt('Output Format').'</th>';
-    $Str .= '<th>'.'&nbsp;'.'</th>';
-    $Str .= '</tr>'."\n";
+    $Str .= '<th>'.&mt('Options').'</th>';
+    $Str .= &Apache::loncommon::end_data_table_header_row();
     #
-    $Str .= '<tr><td align="center">'."\n";
+    $Str .= &Apache::loncommon::start_data_table_row();
+    $Str .= '<td align="center">'."\n";
     $Str .= &Apache::lonstatistics::SectionSelect('Section','multiple',5);
     $Str .= '</td>';
     #
@@ -641,7 +655,7 @@ sub CreateInterface {
     # Render problem checkbox
     my $prob_checkbox = '<input type="checkbox" name="renderprob" ';
     if (exists($env{'form.renderprob'}) && $env{'form.renderprob'} eq 'true') {
-        $prob_checkbox .= 'checked ';
+        $prob_checkbox .= 'checked="checked" ';
     }
     $prob_checkbox .= 'value="true" />';
     $Str .= '<td align="right" valign="top">'.
@@ -650,13 +664,15 @@ sub CreateInterface {
         '<label><b>'.
         '</td>';
     #
-    $Str .= '</tr>'."\n";
-    $Str .= '</table>'."\n";
+    $Str .= &Apache::loncommon::end_data_table_row();
+    $Str .= &Apache::loncommon::end_data_table();
     #
-    $Str .= '<nobr>'.&mt('Status: [_1]',
-                         '<input type="text" '.
-                         'name="stats_status" size="60" value="" />').
-            '</nobr>'.'</p>';    
+    $Str .= '<p><span class="LC_nobreak">'
+           .&mt('Status: [_1]',
+                    '<input type="text" name="stats_status"'
+                   .' size="60" value="" readonly="readonly" />')
+           .'</span></p>';
+    $Str .= '</p>';
     ##
     return $Str;
 }
