@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: startup.pl,v 1.32 2007/12/23 04:41:19 raeburn Exp $
+# $Id: startup.pl,v 1.33 2008/07/13 17:38:55 raeburn Exp $
 
 BEGIN {
     eval "use Apache2::compat();";
@@ -144,6 +144,10 @@ use Apache::longroup();
 use Apache::groupboards();
 use Apache::lonclonecourse();
 use Apache::lonuserutils();
+use Apache::coursecatalog();
+use Apache::courseclassifier();
+use Apache::selfenroll();
+use Apache::createaccount();
 1;
 __END__
 
