@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # TeX Conversion Module
 #
-# $Id: lontexconvert.pm,v 1.90 2008/11/18 10:02:56 hauer Exp $
+# $Id: lontexconvert.pm,v 1.94 2009/01/02 01:22:33 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -47,7 +47,9 @@ use Apache::lonlocal;
 use Apache::lonnet;
 use lib '/home/httpd/lib/perl/';
 use LONCAPA;
- 
+use URI::Escape;
+use IO::Socket::INET;
+use IO::Socket::SSL;
 
 # ====================================================================== Header
 
@@ -79,10 +81,7 @@ sub init_tth {
 
 $Apache::lontexconvert::messedup=0;
 
-# we need this routine because &converted can get called from inside
-# of the safespace (through &xmlparse('<m>stuff</m>') which doesn't
-# allow the opcode for alarm, so we need to compile this before we get
-# into the safe space since opcode checks only occur at compile time
+
 sub convert_real {
     my ($texstring)=@_;
     my ($xmlstring,$errorstring);
@@ -244,6 +243,43 @@ sub init_math_support {
     return;
 }
 
+sub mimetex_valign {
+    my ($esc_texstring)=@_;
+    my $valign = 0;
+    my $lonhost = $Apache::lonnet::perlvar{'lonHostID'};
+    my $hostname = &Apache::lonnet::hostname($lonhost);
+    my $protocol = $Apache::lonnet::protocol{$lonhost};
+    my $path = '/cgi-bin/mimetex.cgi?'.$esc_texstring;
+    my $socket;
+    &Apache::lonxml::start_alarm();
+    if ($protocol eq 'https') {
+        $socket = IO::Socket::SSL->new(PeerAddr => $hostname,
+                                       PeerPort => 'https(443)',
+                                       Proto    => 'tcp');
+    } else {
+        $socket = IO::Socket::INET->new(PeerAddr => $hostname,
+                                        PeerPort => 'http(80)',
+                                        Proto    => 'tcp');
+    }
+    if ($socket) {
+        my $headreq = "HEAD $path HTTP/1.0 User-Agent: Mozilla/5.0 \r\n\r\n";
+        print $socket $headreq;
+        while (<$socket>) {
+            if (/Vertical\-Align\:\s*?([\-\d]+)/) {
+                $valign = $1;
+            }
+        }
+        if ($protocol eq 'https') {
+            $socket->close(SSL_no_shutdown => 1,
+                           SSL_ctx_free => 1);
+        } else {
+            $socket->close();
+        }
+    }
+    &Apache::lonxml::end_alarm();
+    return $valign;
+}
+
 sub mimetex_converted {
     my $texstring=shift;
     my $displaystyle=&displaystyle($texstring);
@@ -253,7 +289,9 @@ sub mimetex_converted {
     if ($displaystyle) {
 	$$texstring='\\displaystyle \\Large '.$$texstring;
     }
-    my $result='<img src="/cgi-bin/mimetex.cgi?'.&escape($$texstring).'" alt="$'.$$texstring.'$" />';
+    my $esc_texstring = &uri_escape($$texstring);
+    my $valign = &mimetex_valign($esc_texstring);
+    my $result='<img src="/cgi-bin/mimetex.cgi?'.$esc_texstring.'" style="vertical-align:'.$valign.'px" alt="$'.$$texstring.'$" />';
     if ($displaystyle) {
 	$result='<center>'.$result.'</center>';
     }
@@ -419,8 +457,78 @@ sub postprocess_algebra {
 __END__
 
 
+=pod
 
+=head1 NAME
 
+Apache::lontexconvert;
+
+=head1 SYNOPSIS
+
+Access to tth/ttm
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+
+=head1 SUBROUTINES
+
+=over
+
+=item init_tth()
+
+Header
+
+=item convert_real()
+
+ we need this routine because &converted can get called from inside
+ of the safespace (through &xmlparse('<m>stuff</m>') which doesn't
+ allow the opcode for alarm, so we need to compile this before we get
+ into the safe space since opcode checks only occur at compile time
+
+=item tth_converted()
+
+
+=item clean_out_math_mode()
+
+
+=item displaystyle()
+
+
+=item jsMath_converted()
+
+
+=item tex_engine()
+
+
+=item init_math_support()
+
+
+=item mimetex_converted()
+
+
+=item converted()
+
+
+=item to_convert()
+
+message display
+
+=item smiley()
+
+???
+
+=item msgtexconverted()
+
+=item algebra()
+
+=item prepare_algebra()
+
+=item postprocess_algebra()
+
+=back
+
+=cut
 
 
 
