@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Wrapper for external and binary files as standalone resources
 #
-# $Id: lonwrapper.pm,v 1.28 2008/03/03 19:57:28 www Exp $
+# $Id: lonwrapper.pm,v 1.28.2.1 2008/12/21 04:49:58 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -88,7 +88,7 @@ sub wrapper {
 	&Apache::loncommon::end_page({'frameset' => 1});
     
     foreach my $url ($topurl,$bottomurl) {
-	if ($url !~ /^http:/) {
+	if ($url !~ /^https?\:/) {
 	    $url = &Apache::lonenc::check_encrypt($url);
 	}
     }
